@@ -4,16 +4,11 @@
 #include <osmocom/abis/ipa.h>
 #include <osmocom/rspro/RsproPDU.h>
 
-#include "rspro_util.h"
-
 enum server_conn_fsm_event {
-	SRVC_E_ESTABLISH,	/* instruct SRVC to (re)etablish TCP connection to bankd */
 	SRVC_E_TCP_UP,
 	SRVC_E_TCP_DOWN,
 	SRVC_E_KA_TIMEOUT,
-	SRVC_E_KA_TERMINATED,
 	SRVC_E_CLIENT_CONN_RES,
-	SRVC_E_RSPRO_TX		/* transmit a RSPRO PDU to the peer */
 };
 
 struct rspro_server_conn;
@@ -47,5 +42,6 @@ struct rspro_server_conn {
 	} bankd;
 };
 
+int ipa_client_conn_send_rspro(struct ipa_client_conn *ipa, RsproPDU_t *rspro);
 int server_conn_send_rspro(struct rspro_server_conn *srvc, RsproPDU_t *rspro);
 int server_conn_fsm_alloc(void *ctx, struct rspro_server_conn *srvc);
