@@ -219,7 +219,7 @@ static void clnt_st_wait_cl_conf_res(struct osmo_fsm_inst *fi, uint32_t event, v
 static void _update_client_for_slotmap(struct slot_mapping *map, struct rspro_server *srv,
 					struct rspro_client_conn *bankd_conn)
 {
-	struct rspro_client_conn *conn;
+	struct rspro_client_conn *conn = client_conn_by_slot(srv, &map->client);
 	char ip_str[INET6_ADDRSTRLEN];
 	char port_str[6];
 	uint32_t bankd_ip;
@@ -230,7 +230,6 @@ static void _update_client_for_slotmap(struct slot_mapping *map, struct rspro_se
 	OSMO_ASSERT(map);
 	OSMO_ASSERT(srv);
 
-	conn = client_conn_by_slot(srv, &map->client);
 	if (!conn)
 		LOGP(DMAIN, LOGL_DEBUG, "%s\n", __func__);
 	else
@@ -250,25 +249,20 @@ static void _update_client_for_slotmap(struct slot_mapping *map, struct rspro_se
 	/* if caller didn't provide bankd_conn, resolve it from map */
 	if (!bankd_conn)
 		bankd_conn = bankd_conn_by_id(srv, map->bank.bank_id);
-	if (map->state == SLMAP_S_DELETING || !bankd_conn) {
-		bankd_ip = 0;
-		bankd_port = 0;
-	} else {
-		/* obtain IP and port of bankd */
-		rc = osmo_sock_get_ip_and_port(bankd_conn->peer->ofd.fd, ip_str, sizeof(ip_str),
-						port_str, sizeof(port_str), false);
-		if (rc < 0) {
-			LOGPFSM(bankd_conn->fi, "Error during getpeername\n");
-			return;
-		}
-		bankd_ip = ntohl(inet_addr(ip_str));
-		bankd_port = 9999; /* TODO: configurable */
-	}
+	if (!bankd_conn)
+		return;
 
-	/* determine if IP/port of bankd have changed */
+	/* obtain IP and port of bankd */
+	rc = osmo_sock_get_ip_and_port(bankd_conn->peer->ofd.fd, ip_str, sizeof(ip_str),
+					port_str, sizeof(port_str), false);
+	if (rc < 0) {
+		LOGPFSM(bankd_conn->fi, "Error during getpeername\n");
+		return;
+	}
+	bankd_ip = ntohl(inet_addr(ip_str));
+	bankd_port = 9999; /* TODO: configurable */
 	if (conn->client.bankd.port != bankd_port || conn->client.bankd.ip != bankd_ip) {
-		struct in_addr ia = { .s_addr = bankd_ip };
-		LOGPFSM(conn->fi, "Bankd IP/Port changed to %s:%u\n", inet_ntoa(ia), bankd_port);
+		LOGPFSM(conn->fi, "Bankd IP/Port changed to %s:%s\n", ip_str, port_str);
 		conn->client.bankd.ip = bankd_ip;
 		conn->client.bankd.port = bankd_port;
 		changed = true;
@@ -376,11 +370,9 @@ static void clnt_st_connected_bankd(struct osmo_fsm_inst *fi, uint32_t event, vo
 			break;
 		}
 		slotmaps_unlock(slotmaps);
-		/* update client! */
-		OSMO_ASSERT(map->state == SLMAP_S_DELETING);
-		_update_client_for_slotmap(map, conn->srv, conn);
 		/* slotmap_del() will remove it from both global and bank list */
 		slotmap_del(map->maps, map);
+		/* FIXME: update client! */
 		break;
 	case CLNTC_E_PUSH: /* check if any create or delete requests are pending */
 		slotmaps_wrlock(slotmaps);
